<?php
/**
 * WooCommerce compatibility and custom functions
 *
 * @package    OneType
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2017, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 *
 * @return void
 */
function onetype_woocommerce_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'onetype_woocommerce_setup' );

/**
 * WooCommerce specific scripts & stylesheets.
 */
function onetype_woocommerce_scripts() {
	$font_path   = WC()->plugin_url() . '/assets/fonts/';
	$inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				url("' . $font_path . 'star.woff") format("woff"),
				url("' . $font_path . 'star.ttf") format("truetype"),
				url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: normal;
			font-style: normal;
		}';
	wp_add_inline_style( 'onetype-style', $inline_font );
}
add_action( 'wp_enqueue_scripts', 'onetype_woocommerce_scripts' );

/**
 * Define WooCommerce image sizes.
 */
function onetype_woocommerce_image_dimensions() {
	global $pagenow;

	if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
		return;
	}

  	$catalog = array(
		'width' 	=> '600',
		'height'	=> '600',
		'crop'		=> 1
	);
	$single = array(
		'width' 	=> '600',
		'height'	=> '600',
		'crop'		=> 1
	);
	$thumbnail = array(
		'width' 	=> '180',
		'height'	=> '180',
		'crop'		=> 1
	);

	// Image sizes
	update_option( 'shop_catalog_image_size',   $catalog );     // Product category thumbs
	update_option( 'shop_single_image_size',    $single );       // Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail ); // Image gallery thumbs

}
// add_action( 'after_switch_theme', 'onetype_woocommerce_image_dimensions', 1 );

/**
 * Cart Fragments
 * Ensure cart contents update when products are added to the cart via AJAX
 */
function onetype_cart_link_fragment( $fragments ) {
	global $woocommerce;
	ob_start();
	onetype_cart_link();
	$fragments['a.cart-contents'] = ob_get_clean();
	return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'onetype_cart_link_fragment' );

/**
 * Related Products Args
 */
function onetype_related_products_args( $args ) {
	$args = apply_filters( 'onetype_related_products_args', array(
		'posts_per_page' => 3,
		'columns'        => 3,
	) );

	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'onetype_related_products_args' );

/**
 * Product gallery thumnail columns.
 */
function onetype_thumbnail_columns() {
	return intval( apply_filters( 'onetype_product_thumbnail_columns', 4 ) );
}
add_filter( 'woocommerce_product_thumbnails_columns', 'onetype_thumbnail_columns' );

/**
 * Products per page
 */
function onetype_products_per_page() {
	return intval( apply_filters( 'onetype_products_per_page', 12 ) );
}
add_filter( 'loop_shop_per_page', 'onetype_products_per_page' );

/**
 * Default loop columns on product archives
 *
 * @since  1.0.0
 */
function onetype_loop_columns() {
	return apply_filters( 'onetype_loop_columns', 3 ); // 3 products per row
}
add_filter( 'loop_shop_columns', 'onetype_loop_columns' );

/**
 * Limit cross sells to 2
 */
function onetype_cross_sells_limit() {
	return 2;
}
add_filter( 'woocommerce_cross_sells_total', 'onetype_cross_sells_limit' );

/**
 * WooCommerce pages layout
 */
function onetype_woo_layouts( $layout ) {

	// Get the customizer data.
	$layouts = get_theme_mod( 'onetype_shop_layouts', '2c-r' );

	if ( is_shop() ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = $layouts;
		}
	}

	if ( is_cart() || is_checkout() ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'onetype_woo_layouts', 15 );

/**
 * Extend shop title
 */
function onetype_extend_shop_title( $title ) {
	if ( is_shop() ) {
		$title = esc_html__( 'Shop', 'onetype' );
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'onetype_extend_shop_title' );

function onetype_remove_woo_part() {

	if ( is_front_page() || is_home() ) {
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
	}

}
add_action( 'init', 'onetype_remove_woo_part' );

/**
 * Set featured image as page header background.
 */
function onetype_shop_header_bg() {

	// Show only on post and page
	if ( !is_shop() ) {
		return;
	}

	// Get the featured image
	$img_id = get_theme_mod( 'onetype_shop_featured_img' );
	$img    = wp_get_attachment_image_src( absint( $img_id ), 'full' );

	// Display the custom header via inline CSS.
	if ( $img ) :
		$css = '
			.page-header {
				background-image: url("' . esc_url( $img[0] ) . '");
				background-size: cover;
				background-repeat: no-repeat;
				background-position: 50% 50%;
			}';
	endif;

	if ( ! empty( $css ) ) :
		wp_add_inline_style( 'onetype-style', $css );
	endif;

}
add_action( 'wp_enqueue_scripts', 'onetype_shop_header_bg' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function onetype_shop_body_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( is_shop() ) {
		if ( has_post_thumbnail( get_the_ID() ) ) {
			$classes[] = 'has-post-thumbnail';
		}
	}

	return $classes;
}
add_filter( 'body_class', 'onetype_shop_body_classes' );
